@@ -11,6 +11,9 @@ from config import java
 from util import newTempfile, runcmd
 from logger import LOG
 
+from zope.interface import implements
+from interfaces import IFOConverter
+
 xinc_home = os.environ.get('XINC_HOME')
 
 def _check_xinc():
@@ -26,16 +29,20 @@ def _check_xinc():
 
 xinc_available = _check_xinc()
 
-def fo2pdf(fo_filename, output_filename=None):
-    """ Convert a FO file to PDF using XINC """
+class PDFConverter(object):
 
-    if not output_filename:
-        output_filename = newTempfile(suffix='.pdf')
+    implements(IFOConverter)
 
-    cmd = '"%s/bin/unix/xinc" -fo "%s" -pdf "%s"' % (xinc_home, fo_filename, output_filename)
-    status, output = runcmd(cmd)
-    if status != 0:
-        raise RuntimeError('Error executing: %s' % cmd)
+    def convert(self, fo_filename, output_filename=None):
+        """ Convert a FO file to PDF using XINC """
 
-    return output_filename
+        if not output_filename:
+            output_filename = newTempfile(suffix='.pdf')
+
+        cmd = '"%s/bin/unix/xinc" -fo "%s" -pdf "%s"' % (xinc_home, fo_filename, output_filename)
+        status, output = runcmd(cmd)
+        if status != 0:
+            raise RuntimeError('Error executing: %s' % cmd)
+
+        return output_filename
 
