@@ -37,5 +37,7 @@ def runcmd(cmd):
         status = p.wait()
         stdout_ = p.stdout.read().strip()
         stderr_ = p.stderr.read().strip()
+        print stdout_
+        print stderr_
         return status, stdout_ + stderr_
 
